@@ -33,7 +33,7 @@
    notice and this permission notice appear in supporting documentation.  This
    software is provided "as is" without express or implied warranty.
 
-   Derived "imagsize" program Copyright (C)2004-2020 by Brian Lindholm.  All
+   Derived "imagsize" program Copyright (C)2004-2024 by Brian Lindholm.  All
    rights reserved.  Redistribution is permitted as described as above.  */
 
 
@@ -156,10 +156,10 @@ static int jpeg (FILE *f, int *widthP, int *heightP, double *qual,
 static int xbm (FILE *f, int *widthP, int *heightP);
 static int xpm (FILE *f, int *widthP, int *heightP, int *depth);
 static int ppm (FILE *f, int *widthP, int *heightP);
-static int png (FILE *f, int *widthP, int *heightP, int *bpp,
-  int *typenum);
+static int png (FILE *f, int *widthP, int *heightP, int *bpp, int *typenum);
 static int tiff_be (FILE *f, int *widthP, int *heightP, int *depth);
 static int tiff_le (FILE *f, int *widthP, int *heightP, int *depth);
+static int webp (FILE *f, int *widthP, int *heightP, int *depth, int *typenum);
 static int image_size (FILE *f, int *widthP, int *heightP, double *qual,
   int *depth, char *type, char *sample);
 
@@ -772,6 +772,76 @@ png (FILE *f, int *widthP, int *heightP, int *bpp, int *typenum)
 }
 
 
+static int
+webp (FILE *f, int *widthP, int *heightP, int *depth, int *typenum)
+{
+  unsigned char ch1, ch2, ch3, ch4, l1, l2, l3, l4, h1, h2, h3, r1, r2, r3, r4, w1, w2, w3;
+  long l, val;
+  char line[500], name_and_type[500];
+
+  /* Read rest of signature. */
+  if (!mustbe (f, 'F')) return (NOT_OK);
+  if (!mustbe (f, 'F')) return (NOT_OK);
+  if (fseek (f, 4, 1)) return (NOT_OK);
+  if (!mustbe (f, 'W')) return (NOT_OK);
+  if (!mustbe (f, 'E')) return (NOT_OK);
+  if (!mustbe (f, 'B')) return (NOT_OK);
+  if (!mustbe (f, 'P')) return (NOT_OK);
+
+  /* scan through files for chunks */
+  while (!feof (f))
+    {
+      /* Read chunk header. */
+      if (!get (f, &ch1)) return (NOT_OK);
+      if (!get (f, &ch2)) return (NOT_OK);
+      if (!get (f, &ch3)) return (NOT_OK);
+      if (!get (f, &ch4)) return (NOT_OK);
+
+      /* Read chunk size. */
+      if (!get (f, &l1)) return (NOT_OK);
+      if (!get (f, &l2)) return (NOT_OK);
+      if (!get (f, &l3)) return (NOT_OK);
+      if (!get (f, &l4)) return (NOT_OK);
+      l = (long) l4 * 16777216 + (long) l3 * 65536 + (long) l2 * 256 + (long) l1;
+
+      /* Is this a VP8 chunk? */
+      if (ch1 == (unsigned char) 'V' && ch2 == (unsigned char) 'P' && ch3 == (unsigned char) '8')
+        {
+          if (ch4 == (unsigned char) ' ')
+            {
+              *typenum = 1;
+              if (fseek (f, 6, 1)) return (NOT_OK);
+              if (!get (f, &w1)) return (NOT_OK);
+              if (!get (f, &w2)) return (NOT_OK);
+              *widthP = (int) w2 * 256 + (int) w1;
+              if (!get (f, &h1)) return (NOT_OK);
+              if (!get (f, &h2)) return (NOT_OK);
+              *heightP = (int) h2 * 256 + (int) h1;
+              *depth = 24;
+              return (OK);
+            }
+          else if (ch4 == (unsigned char) 'L')
+            {
+              *typenum = 2;
+              if (fseek (f, 1, 1)) return (NOT_OK);
+              if (!get (f, &r1)) return (NOT_OK);
+              if (!get (f, &r2)) return (NOT_OK);
+              if (!get (f, &r3)) return (NOT_OK);
+              if (!get (f, &r4)) return (NOT_OK);
+              l = (long) r4 * 16777216 + (long) r3 * 65536 + (long) r2 * 256 + (long) r1;
+              *widthP = (l & 16383) + 1;
+              *heightP = ((l >> 14) & 16383) + 1;
+              *depth = 24;
+              return (OK);
+            }
+        }
+      /* Not the block we want.  Skip it. */
+      if (fseek (f, l, 1)) return (NOT_OK);
+    }
+  return (failure ("imagsize error: WEBP size not found"));
+}
+
+
 static int
 image_size (FILE *f, int *widthP, int *heightP, double *qual,
             int *depth, char *type, char *sampling)
@@ -819,6 +889,17 @@ image_size (FILE *f, int *widthP, int *heightP, double *qual,
         strcpy (type, "jpg-unknown");
       return (rc);
     }
+  else if (ch1 == (unsigned char) 'R' && ch2 == (unsigned char) 'I')
+    {
+      rc = webp (f, widthP, heightP, depth, &typenum);
+      if (typenum == 1)
+        strcpy (type, "webp-vp8");
+      else if (typenum == 2)
+        strcpy (type, "webp-lossless");
+      else
+        strcpy (type, "webp-unknown");
+      return (rc);
+    }
   else if (ch1 == (unsigned char) '#' && ch2 == (unsigned char) 'd')
     {
       rc = xbm (f, widthP, heightP);
