@@ -1,6 +1,6 @@
 /* filehash:  Print various hash digests and filesizes for specified files.
 
-   Copyright (C) 2004-2022 by Brian Lindholm.
+   Copyright (C) 2004-2024 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The filehash utility is free software; you can redistribute it and/or modify
@@ -251,7 +251,7 @@ print_filehash (char *filename, off_t offset, off_t read_bytes, int print_size,
             else if (classic == 1) {
               fprintf (stdout, "SIZE (%s) = ", filename);
               fprintf (stdout, sizefmt, file_stats.st_size);
-              fprintf (stdout, "\n", filename);
+              fprintf (stdout, "\n");
             }
             else {
               if (not_first)
